// utm-tracking.js

// Function to get URL parameters
function getParameterByName(name) {
    name = name.replace(/[\[]/, "\\[").replace(/[\]]/, "\\]");
    var regex = new RegExp("[\\?&]" + name + "=([^&#]*)"),
        results = regex.exec(location.search);
    return results === null ? "" : decodeURIComponent(results[1].replace(/\+/g, " "));
}

// Store UTM parameters in session storage
const utmParams = ['utm_source', 'utm_medium', 'utm_campaign', 'utm_term', 'utm_content'];
utmParams.forEach(param => {
    const value = getParameterByName(param);
    if (value) {
        sessionStorage.setItem(param, value);
    }
});

// Function to append UTM parameters to URL
function appendUtmParams(url) {
    let newUrl = new URL(url);
    utmParams.forEach(param => {
        const value = sessionStorage.getItem(param);
        if (value) {
            newUrl.searchParams.set(param, value);
        }
    });
    return newUrl.toString();
}

// Append UTM parameters to all internal links
document.addEventListener('DOMContentLoaded', () => {
    document.querySelectorAll('a').forEach(link => {
        if (link.hostname === location.hostname) {
            link.href = appendUtmParams(link.href);
        }
    });
});

// Populate hidden form fields with UTM parameters
document.addEventListener('DOMContentLoaded', () => {
    utmParams.forEach(param => {
        const value = sessionStorage.getItem(param);
        if (value) {
            const hiddenField = document.querySelector(`input[name="${param}"]`);
            if (hiddenField) {
                hiddenField.value = value;
            }
        }
    });
});
